searchNodes=[{"doc":"Trilean implements a functionally complete three-valued logic, K3+. This is an extension of Kleene&#39;s strong logic of indeterminacy. Three value logics allow reasoning in face of uncertainty. For example iex&gt; will_there_be_a_sea_battle_tomorrow = Trilean.maybe() ...&gt; nice_day_tomorrow = true ...&gt; ...&gt; _should_i_pack_a_picnic = ( ...&gt; will_there_be_a_sea_battle_tomorrow ...&gt; |&gt; Trilean.and(nice_day_tomorrow) ...&gt; |&gt; Trilean.possible?() ...&gt; ) true I should pack a picnic because it will be a nice day and there could be a spectacle to watch. (The sea battle problem is Aristotle&#39;s formulation of the contingent futures problem on which three value logics can shed some light.) iex&gt; will_there_be_a_sea_battle_tomorrow = Trilean.maybe() ...&gt; nice_day_tomorrow = false ...&gt; ...&gt; _should_i_pack_a_picnic = ( ...&gt; will_there_be_a_sea_battle_tomorrow ...&gt; |&gt; Trilean.and(nice_day_tomorrow) ...&gt; |&gt; Trilean.possible?() ...&gt; ) false I should not pack a picnic even though there could be a spectacle because it will be a crummy day. All expressions evaluate the same as they would in normal boolean logic if their inputs are true or false. If, however, one or more of the inputs is :maybe then the output may become indeterminate. For example: iex&gt; Trilean.and(true, true) true iex&gt; Trilean.and(true, false) false iex&gt; Trilean.and(true, Trilean.maybe()) Trilean.maybe()","ref":"Trilean.html","title":"Trilean","type":"module"},{"doc":"Logical conjunction (∧) Truth table FMT FFFF MFMM TFMT Examples iex&gt; Trilean.and(true, true) true iex&gt; Trilean.and(true, Trilean.maybe()) Trilean.maybe() iex&gt; Trilean.and(true, false) false iex&gt; Trilean.and(false, Trilean.maybe()) false","ref":"Trilean.html#and/2","title":"Trilean.and/2","type":"function"},{"doc":"Logical cyclic negation Truth table Acyclic not(A) FT MF TM Examples iex&gt; Trilean.cyc_neg(true) Trilean.maybe() iex&gt; Trilean.cyc_neg(false) true iex&gt; Trilean.cyc_neg(Trilean.maybe()) false","ref":"Trilean.html#cyc_neg/1","title":"Trilean.cyc_neg/1","type":"function"},{"doc":"Logical equivalence (↔ or ≡) Truth table FMT FTMF MMMM TFMT Examples iex&gt; Trilean.equivalence(true, true) true iex&gt; Trilean.equivalence(false, false) true iex&gt; Trilean.equivalence(Trilean.maybe(), false) Trilean.maybe()","ref":"Trilean.html#equivalence/2","title":"Trilean.equivalence/2","type":"function"},{"doc":"Return the false value. This provided for symmetry with maybe/0.","ref":"Trilean.html#false/0","title":"Trilean.false/0","type":"function"},{"doc":"Material implication (→ or ⊃) Truth table FMT FTTT MMMT TFMT Examples iex&gt; Trilean.implies(true, true) true iex&gt; Trilean.implies(true, false) false iex&gt; Trilean.implies(Trilean.maybe(), false) Trilean.maybe() iex&gt; Trilean.implies(Trilean.maybe(), Trilean.maybe()) Trilean.maybe() iex&gt; Trilean.implies(false, false) true iex&gt; Trilean.implies(false, true) true","ref":"Trilean.html#implies/2","title":"Trilean.implies/2","type":"function"},{"doc":"Returns the maybe value","ref":"Trilean.html#maybe/0","title":"Trilean.maybe/0","type":"function"},{"doc":"Implementation of I unary logic operator. &quot;it is unknown that...&quot; or &quot;it is contingent that...&quot;. AI(A) FF MT TF Examples iex&gt; Trilean.maybe?(false) false iex&gt; Trilean.maybe?(Trilean.maybe()) true iex&gt; Trilean.maybe?(true) false","ref":"Trilean.html#maybe?/1","title":"Trilean.maybe?/1","type":"function"},{"doc":"Logical negation or complement (¬) Truth table A¬A FT MM TF Examples iex&gt; Trilean.not(true) false iex&gt; Trilean.not(false) true iex&gt; Trilean.not(Trilean.maybe()) Trilean.maybe()","ref":"Trilean.html#not/1","title":"Trilean.not/1","type":"function"},{"doc":"Logical disjunction (∨) Truth table FMT FFMT MMMt TTTT Examples iex&gt; Trilean.or(true, true) true iex&gt; Trilean.or(true, false) true iex&gt; Trilean.or(true, Trilean.maybe()) true iex&gt; Trilean.or(false, false) false iex&gt; Trilean.or(false, Trilean.maybe()) Trilean.maybe()","ref":"Trilean.html#or/2","title":"Trilean.or/2","type":"function"},{"doc":"Logical possibility (or M or ◇) A◇A FF MT TT Examples iex&gt; Trilean.possible?(false) false iex&gt; Trilean.possible?(Trilean.maybe()) true iex&gt; Trilean.possible?(true) true","ref":"Trilean.html#possible?/1","title":"Trilean.possible?/1","type":"function"},{"doc":"Returns the true value. This provided for symmetry with maybe/0.","ref":"Trilean.html#true/0","title":"Trilean.true/0","type":"function"},{"doc":"Logical necessity (or L or □) Truth table A□A FT MF TT Examples iex&gt; Trilean.true?(false) false iex&gt; Trilean.true?(Trilean.maybe()) false iex&gt; Trilean.true?(true) true","ref":"Trilean.html#true?/1","title":"Trilean.true?/1","type":"function"},{"doc":"A trinary logical value: true, false, or maybe","ref":"Trilean.html#t:t/0","title":"Trilean.t/0","type":"type"},{"doc":"Guard expressions for three-valued logic. Example iex&gt; defmodule Picnic do ...&gt; use Trilean.Guards ...&gt; use Trilean.Operators ...&gt; ...&gt; def pack_one?(sea_battle, nice_day) when is_possible(sea_battle), ...&gt; do: (sea_battle &amp;&amp;&amp; nice_day) |&gt; Trilean.possible? ...&gt; def pack_one(_,_), do: false ...&gt; end ...&gt; ...&gt; Picnic.pack_one?(Trilean.maybe(), true) true","ref":"Trilean.Guards.html","title":"Trilean.Guards","type":"module"},{"doc":"Returns true if term is false; otherwise returns false. Can be used in guard expressions. iex&gt; (fn x when Trilean.Guards.is_false(x) -&gt; :is_false; _ -&gt; :not_false end).(false) :is_false iex&gt; (fn x when Trilean.Guards.is_false(x) -&gt; :is_false; _ -&gt; :not_false end).(true) :not_false iex&gt; (fn x when Trilean.Guards.is_false(x) -&gt; :is_false; _ -&gt; :not_false end).(Trilean.maybe()) :not_false iex&gt; (fn x when Trilean.Guards.is_false(x) -&gt; :is_false; _ -&gt; :not_false end).(:bacon) :not_false","ref":"Trilean.Guards.html#is_false/1","title":"Trilean.Guards.is_false/1","type":"macro"},{"doc":"Returns true if term is maybe; otherwise returns false. Can be used in guard expressions. iex&gt; (fn x when Trilean.Guards.is_maybe(x) -&gt; :is_maybe; _ -&gt; :not_maybe end).(Trilean.maybe()) :is_maybe iex&gt; (fn x when Trilean.Guards.is_maybe(x) -&gt; :is_maybe; _ -&gt; :not_maybe end).(false) :not_maybe iex&gt; (fn x when Trilean.Guards.is_maybe(x) -&gt; :is_maybe; _ -&gt; :not_maybe end).(true) :not_maybe iex&gt; (fn x when Trilean.Guards.is_maybe(x) -&gt; :is_maybe; _ -&gt; :not_maybe end).(:bacon) :not_maybe","ref":"Trilean.Guards.html#is_maybe/1","title":"Trilean.Guards.is_maybe/1","type":"macro"},{"doc":"Returns false if term is false; otherwise returns true. Can be used in guard expressions. iex&gt; (fn x when Trilean.Guards.is_possible(x) -&gt; :is_possible; _ -&gt; :not_possible end).(Trilean.maybe()) :is_possible iex&gt; (fn x when Trilean.Guards.is_possible(x) -&gt; :is_possible; _ -&gt; :not_possible end).(false) :not_possible iex&gt; (fn x when Trilean.Guards.is_possible(x) -&gt; :is_possible; _ -&gt; :not_possible end).(true) :is_possible iex&gt; (fn x when Trilean.Guards.is_possible(x) -&gt; :is_possible; _ -&gt; :not_possible end).(:bacon) :not_possible","ref":"Trilean.Guards.html#is_possible/1","title":"Trilean.Guards.is_possible/1","type":"macro"},{"doc":"Returns true if term is a Trilean.t() value; otherwise returns false. Can be used in guard expressions. iex&gt; (fn x when Trilean.Guards.is_trilean(x) -&gt; :is_trilean; _ -&gt; :not_trilean end).(false) :is_trilean iex&gt; (fn x when Trilean.Guards.is_trilean(x) -&gt; :is_trilean; _ -&gt; :not_trilean end).(true) :is_trilean iex&gt; (fn x when Trilean.Guards.is_trilean(x) -&gt; :is_trilean; _ -&gt; :not_trilean end).(Trilean.maybe()) :is_trilean iex&gt; (fn x when Trilean.Guards.is_trilean(x) -&gt; :is_trilean; _ -&gt; :not_trilean end).(:bacon) :not_trilean","ref":"Trilean.Guards.html#is_trilean/1","title":"Trilean.Guards.is_trilean/1","type":"macro"},{"doc":"Returns true if term is true; otherwise returns false. Can be used in guard expressions. iex&gt; (fn x when Trilean.Guards.is_true(x) -&gt; :is_true; _ -&gt; :not_true end).(Trilean.maybe()) :not_true iex&gt; (fn x when Trilean.Guards.is_true(x) -&gt; :is_true; _ -&gt; :not_true end).(false) :not_true iex&gt; (fn x when Trilean.Guards.is_true(x) -&gt; :is_true; _ -&gt; :not_true end).(true) :is_true iex&gt; (fn x when Trilean.Guards.is_true(x) -&gt; :is_true; _ -&gt; :not_true end).(:bacon) :not_true","ref":"Trilean.Guards.html#is_true/1","title":"Trilean.Guards.is_true/1","type":"macro"},{"doc":"Operators for three-valued logic. These are in conflict with the stdlib Bitwise module, so both modules cannot be in use at the same time. Example iex&gt; use Trilean.Operators ...&gt; will_a_sea_battle_be_fought_tomorrow = maybe() ...&gt; nice_day_tomorrow = true ...&gt; ...&gt; _should_i_pack_a_picnic = ...&gt; (will_a_sea_battle_be_fought_tomorrow &amp;&amp;&amp; nice_day_tomorrow) ...&gt; |&gt; Trilean.possible?() true","ref":"Trilean.Operators.html","title":"Trilean.Operators","type":"module"},{"doc":"See Trilean.and/2 iex&gt; maybe() &amp;&amp;&amp; maybe() maybe() iex&gt; maybe() &amp;&amp;&amp; true maybe() iex&gt; maybe() &amp;&amp;&amp; false false iex&gt; false &amp;&amp;&amp; maybe() false iex&gt; false &amp;&amp;&amp; false false iex&gt; true &amp;&amp;&amp; true true","ref":"Trilean.Operators.html#&&&/2","title":"Trilean.Operators.&&&/2","type":"macro"},{"doc":"See Trilean.equivalence/2 iex&gt; maybe() &lt;~&gt; maybe() maybe() iex&gt; maybe() &lt;~&gt; true maybe() iex&gt; true &lt;~&gt; maybe() maybe() iex&gt; maybe() &lt;~&gt; false maybe() iex&gt; false &lt;~&gt; maybe() maybe() iex&gt; false &lt;~&gt; false true iex&gt; true &lt;~&gt; true true","ref":"Trilean.Operators.html#%3C~%3E/2","title":"Trilean.Operators.<~>/2","type":"macro"},{"doc":"Returns the maybe value iex&gt; maybe() Trilean.maybe()","ref":"Trilean.Operators.html#maybe/0","title":"Trilean.Operators.maybe/0","type":"macro"},{"doc":"See Trilean.or/2 iex&gt; maybe() ||| maybe() maybe() iex&gt; maybe() ||| true true iex&gt; maybe() ||| false maybe() iex&gt; false ||| maybe() maybe() iex&gt; false ||| false false iex&gt; true ||| false true","ref":"Trilean.Operators.html#%7C%7C%7C/2","title":"Trilean.Operators.|||/2","type":"macro"},{"doc":"See Trilean.implies/2 iex&gt; maybe() ~&gt; maybe() maybe() iex&gt; maybe() ~&gt; true true iex&gt; true ~&gt; maybe() maybe() iex&gt; maybe() ~&gt; false maybe() iex&gt; false ~&gt; maybe() true iex&gt; false ~&gt; false true iex&gt; true ~&gt; true true","ref":"Trilean.Operators.html#~%3E/2","title":"Trilean.Operators.~>/2","type":"macro"},{"doc":"See Trilean.not/1 iex&gt; use Trilean.Operators ...&gt; ~~~maybe() maybe() iex&gt; ~~~true false iex&gt; ~~~false true","ref":"Trilean.Operators.html#~~~/1","title":"Trilean.Operators.~~~/1","type":"macro"}]